@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent-template
-version: 2.1.5
-id: persistent-template-2.1.5-b75d3f03ad073bca4fe2b675c1178327
-key: persi_CqmvJbisqq4Gs767joqCNx
+version: 2.1.6
+id: persistent-template-2.1.6-3e2b2abfd0db664ab9870aabea4e1393
+key: persi_L8z5A8Ej9BiEEkAIULMyX5
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -17,22 +17,22 @@ exposed: True
 exposed-modules:
     Database.Persist.TH
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.5
-library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.5
-data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-template-2.1.5
-hs-libraries: HSpersistent-template-2.1.5-CqmvJbisqq4Gs767joqCNx
+import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.6
+library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.6
+data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-template-2.1.6
+hs-libraries: HSpersistent-template-2.1.6-L8z5A8Ej9BiEEkAIULMyX5
 depends:
-    aeson-0.11.0.0-3b69ab8a9952fc7c94fde12b431d717b
-    aeson-compat-0.3.1.0-477156b04fb574ca75dcbd9c0a3687a2
+    aeson-0.11.1.0-01f93b6d659087121e16b9df8deda57c
+    aeson-compat-0.3.1.0-c95719e2055330e8215d485af8816303
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
     http-api-data-0.2.2-107631c0bae2e2a6211651e9a27c130c
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-1a8cc90bb0cf2afc03da9e875eb23203
+    monad-logger-0.3.18-cd8d51c949646894888975572eea97f1
     path-pieces-0.2.1-c4c6ea4593a7da7123f92fac6c85ebd3
-    persistent-2.2.4-bd2986a850822d0f7f277144476772ce
+    persistent-2.2.4.1-2b50a3e9b6124bb06f6361c04fb03b63
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
